! module with the Hamiltonian function and the Hamilton's equations
module hamiltonian

  use parameters
  implicit none

contains

!***************************************************************************************

  ! Integrable Hamiltonian of the 2:1 mean motion resonance problem
  function Ham(p,x,t)

     implicit none

     type(hamparam),intent(in):: p
     double precision,intent(in):: x(2)
     double precision,intent(in):: t
     double precision:: Ham
     
     double precision:: r2, delta

     !-----------------------------------------------
     r2 = x(1)**2 + x(2)**2
     delta = p%delta + p%ddelta*t
     
     Ham = 0.5d0*delta*r2 + 0.25d0*r2**2 - 2.d0*x(1)
     !-----------------------------------------------

  end function Ham

!***************************************************************************************

  ! right-hand side of the equations of motion of the integrable 2:1 mean motion resonance model
  function DHam(p,x,t)

     implicit none

     type(hamparam),intent(in):: p
     double precision,intent(in):: x(2)
     double precision,intent(in):: t
     double precision:: DHam(2)
     
     double precision:: r2, delta


     !-----------------------------------------------
     r2 = x(1)**2 + x(2)**2
     delta = p%delta + p%ddelta*t

     DHam(1) = delta*x(2) + r2*x(2) 
     DHam(2) = - delta*x(1) - r2*x(1) + 2.d0 
     !-----------------------------------------------

  end function DHam

!***************************************************************************************


end module hamiltonian
